# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/review_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/review_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%fsai_grpc_api/protos/review_api.proto\"/\n\x19GetNextReviewImageRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\".\n\x1aGetNextReviewImageResponse\x12\x10\n\x08image_id\x18\x01 \x01(\x05\x32Z\n\tReviewApi\x12M\n\x12GetNextReviewImage\x12\x1a.GetNextReviewImageRequest\x1a\x1b.GetNextReviewImageResponseb\x06proto3'
)




_GETNEXTREVIEWIMAGEREQUEST = _descriptor.Descriptor(
  name='GetNextReviewImageRequest',
  full_name='GetNextReviewImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetNextReviewImageRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=88,
)


_GETNEXTREVIEWIMAGERESPONSE = _descriptor.Descriptor(
  name='GetNextReviewImageResponse',
  full_name='GetNextReviewImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='GetNextReviewImageResponse.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=136,
)

DESCRIPTOR.message_types_by_name['GetNextReviewImageRequest'] = _GETNEXTREVIEWIMAGEREQUEST
DESCRIPTOR.message_types_by_name['GetNextReviewImageResponse'] = _GETNEXTREVIEWIMAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNextReviewImageRequest = _reflection.GeneratedProtocolMessageType('GetNextReviewImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTREVIEWIMAGEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.review_api_pb2'
  # @@protoc_insertion_point(class_scope:GetNextReviewImageRequest)
  })
_sym_db.RegisterMessage(GetNextReviewImageRequest)

GetNextReviewImageResponse = _reflection.GeneratedProtocolMessageType('GetNextReviewImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTREVIEWIMAGERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.review_api_pb2'
  # @@protoc_insertion_point(class_scope:GetNextReviewImageResponse)
  })
_sym_db.RegisterMessage(GetNextReviewImageResponse)



_REVIEWAPI = _descriptor.ServiceDescriptor(
  name='ReviewApi',
  full_name='ReviewApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=138,
  serialized_end=228,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNextReviewImage',
    full_name='ReviewApi.GetNextReviewImage',
    index=0,
    containing_service=None,
    input_type=_GETNEXTREVIEWIMAGEREQUEST,
    output_type=_GETNEXTREVIEWIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REVIEWAPI)

DESCRIPTOR.services_by_name['ReviewApi'] = _REVIEWAPI

# @@protoc_insertion_point(module_scope)
